from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from vrt_lss_studio.api.reports_api import ReportsApi
from vrt_lss_studio.api.statistics_api import StatisticsApi
from vrt_lss_studio.api.system_api import SystemApi



# coding: utf-8

"""
    Veeroute.LSS Studio

    LSS Studio Tool API  # noqa: E501

    The version of the OpenAPI document: 3.8.168680
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_studio
from vrt_lss_studio.models.service_statistics import ServiceStatistics  # noqa: E501
from vrt_lss_studio.rest import ApiException

class TestServiceStatistics(unittest.TestCase):
    """ServiceStatistics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ServiceStatistics
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_studio.models.service_statistics.ServiceStatistics()  # noqa: E501
        if include_optional :
            return ServiceStatistics(
                service = 'LASTMILE', 
                methods = [
                    vrt_lss_studio.models.method_statistics.MethodStatistics(
                        method = 'PLAN', 
                        unique_points_per_day = 1500, 
                        points_per_day = 1500, )
                    ]
            )
        else :
            return ServiceStatistics(
                service = 'LASTMILE',
                methods = [
                    vrt_lss_studio.models.method_statistics.MethodStatistics(
                        method = 'PLAN', 
                        unique_points_per_day = 1500, 
                        points_per_day = 1500, )
                    ],
        )

    def testServiceStatistics(self):
        """Test ServiceStatistics"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Veeroute.LSS Studio

    LSS Studio Tool API  # noqa: E501

    The version of the OpenAPI document: 3.8.168680
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from vrt_lss_studio.configuration import Configuration


class TraceData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'str',
        'client': 'str',
        'server': 'str',
        'service': 'ServiceName',
        'method': 'MethodName',
        'time': 'datetime'
    }

    attribute_map = {
        'code': 'code',
        'client': 'client',
        'server': 'server',
        'service': 'service',
        'method': 'method',
        'time': 'time'
    }

    def __init__(self, code=None, client=None, server=None, service=None, method=None, time=None, local_vars_configuration=None):  # noqa: E501
        """TraceData - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._client = None
        self._server = None
        self._service = None
        self._method = None
        self._time = None
        self.discriminator = None

        self.code = code
        if client is not None:
            self.client = client
        if server is not None:
            self.server = server
        if service is not None:
            self.service = service
        if method is not None:
            self.method = method
        if time is not None:
            self.time = time

    @property
    def code(self):
        """Gets the code of this TraceData.  # noqa: E501

        Unique operation code.  # noqa: E501

        :return: The code of this TraceData.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this TraceData.

        Unique operation code.  # noqa: E501

        :param code: The code of this TraceData.  # noqa: E501
        :type code: str
        """
        if self.local_vars_configuration.client_side_validation and code is None:  # noqa: E501
            raise ValueError("Invalid value for `code`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                code is not None and len(code) > 256):
            raise ValueError("Invalid value for `code`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                code is not None and len(code) < 3):
            raise ValueError("Invalid value for `code`, length must be greater than or equal to `3`")  # noqa: E501

        self._code = code

    @property
    def client(self):
        """Gets the client of this TraceData.  # noqa: E501

        Client ID.  # noqa: E501

        :return: The client of this TraceData.  # noqa: E501
        :rtype: str
        """
        return self._client

    @client.setter
    def client(self, client):
        """Sets the client of this TraceData.

        Client ID.  # noqa: E501

        :param client: The client of this TraceData.  # noqa: E501
        :type client: str
        """
        if (self.local_vars_configuration.client_side_validation and
                client is not None and len(client) > 256):
            raise ValueError("Invalid value for `client`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                client is not None and len(client) < 2):
            raise ValueError("Invalid value for `client`, length must be greater than or equal to `2`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                client is not None and not re.search(r'\w+', client)):  # noqa: E501
            raise ValueError(r"Invalid value for `client`, must be a follow pattern or equal to `/\w+/`")  # noqa: E501

        self._client = client

    @property
    def server(self):
        """Gets the server of this TraceData.  # noqa: E501

        Server ID.  # noqa: E501

        :return: The server of this TraceData.  # noqa: E501
        :rtype: str
        """
        return self._server

    @server.setter
    def server(self, server):
        """Sets the server of this TraceData.

        Server ID.  # noqa: E501

        :param server: The server of this TraceData.  # noqa: E501
        :type server: str
        """
        if (self.local_vars_configuration.client_side_validation and
                server is not None and len(server) > 256):
            raise ValueError("Invalid value for `server`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                server is not None and len(server) < 2):
            raise ValueError("Invalid value for `server`, length must be greater than or equal to `2`")  # noqa: E501

        self._server = server

    @property
    def service(self):
        """Gets the service of this TraceData.  # noqa: E501


        :return: The service of this TraceData.  # noqa: E501
        :rtype: ServiceName
        """
        return self._service

    @service.setter
    def service(self, service):
        """Sets the service of this TraceData.


        :param service: The service of this TraceData.  # noqa: E501
        :type service: ServiceName
        """

        self._service = service

    @property
    def method(self):
        """Gets the method of this TraceData.  # noqa: E501


        :return: The method of this TraceData.  # noqa: E501
        :rtype: MethodName
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this TraceData.


        :param method: The method of this TraceData.  # noqa: E501
        :type method: MethodName
        """

        self._method = method

    @property
    def time(self):
        """Gets the time of this TraceData.  # noqa: E501

        Date and time service method run in the [RFC 3339, section 5.6](https://tools.ietf.org/html/rfc3339#section-5.6) format.  # noqa: E501

        :return: The time of this TraceData.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this TraceData.

        Date and time service method run in the [RFC 3339, section 5.6](https://tools.ietf.org/html/rfc3339#section-5.6) format.  # noqa: E501

        :param time: The time of this TraceData.  # noqa: E501
        :type time: datetime
        """

        self._time = time

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TraceData):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TraceData):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Veeroute.LSS Studio

    LSS Studio Tool API  # noqa: E501

    The version of the OpenAPI document: 3.8.168680
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "3.8.168680"

# import apis into sdk package
from vrt_lss_studio.api.reports_api import ReportsApi
from vrt_lss_studio.api.statistics_api import StatisticsApi
from vrt_lss_studio.api.system_api import SystemApi

# import ApiClient
from vrt_lss_studio.api_client import ApiClient
from vrt_lss_studio.configuration import Configuration
from vrt_lss_studio.exceptions import OpenApiException
from vrt_lss_studio.exceptions import ApiTypeError
from vrt_lss_studio.exceptions import ApiValueError
from vrt_lss_studio.exceptions import ApiKeyError
from vrt_lss_studio.exceptions import ApiAttributeError
from vrt_lss_studio.exceptions import ApiException
# import models into sdk package
from vrt_lss_studio.models.check_result import CheckResult
from vrt_lss_studio.models.date_statistics import DateStatistics
from vrt_lss_studio.models.date_window import DateWindow
from vrt_lss_studio.models.inline_response400 import InlineResponse400
from vrt_lss_studio.models.inline_response400_validations import InlineResponse400Validations
from vrt_lss_studio.models.inline_response401 import InlineResponse401
from vrt_lss_studio.models.inline_response403 import InlineResponse403
from vrt_lss_studio.models.inline_response415 import InlineResponse415
from vrt_lss_studio.models.inline_response429 import InlineResponse429
from vrt_lss_studio.models.inline_response500 import InlineResponse500
from vrt_lss_studio.models.inline_response501 import InlineResponse501
from vrt_lss_studio.models.inline_response502 import InlineResponse502
from vrt_lss_studio.models.inline_response503 import InlineResponse503
from vrt_lss_studio.models.inline_response504 import InlineResponse504
from vrt_lss_studio.models.inline_response_default import InlineResponseDefault
from vrt_lss_studio.models.method_name import MethodName
from vrt_lss_studio.models.method_statistics import MethodStatistics
from vrt_lss_studio.models.service_name import ServiceName
from vrt_lss_studio.models.service_statistics import ServiceStatistics
from vrt_lss_studio.models.trace_data import TraceData
from vrt_lss_studio.models.user_report_filter import UserReportFilter
from vrt_lss_studio.models.user_statistics import UserStatistics
from vrt_lss_studio.models.user_statistics_filter import UserStatisticsFilter
from vrt_lss_studio.models.version_result import VersionResult




# coding: utf-8

"""
    Veeroute.LSS Studio

    LSS Studio Tool API  # noqa: E501

    The version of the OpenAPI document: 3.8.168680
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_studio
from vrt_lss_studio.models.user_report_filter import UserReportFilter  # noqa: E501
from vrt_lss_studio.rest import ApiException

class TestUserReportFilter(unittest.TestCase):
    """UserReportFilter unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserReportFilter
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_studio.models.user_report_filter.UserReportFilter()  # noqa: E501
        if include_optional :
            return UserReportFilter(
                name = 'UsageReport', 
                date_window = vrt_lss_studio.models.date_window.DateWindow(
                    from = 'Sun Feb 21 03:00:00 MSK 2021', 
                    to = 'Thu Feb 25 03:00:00 MSK 2021', )
            )
        else :
            return UserReportFilter(
                name = 'UsageReport',
        )

    def testUserReportFilter(self):
        """Test UserReportFilter"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Veeroute.LSS Studio

    LSS Studio Tool API  # noqa: E501

    The version of the OpenAPI document: 3.8.168680
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import vrt_lss_studio
from vrt_lss_studio.api.system_api import SystemApi  # noqa: E501
from vrt_lss_studio.rest import ApiException


class TestSystemApi(unittest.TestCase):
    """SystemApi unit test stubs"""

    def setUp(self):
        self.api = vrt_lss_studio.api.system_api.SystemApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_check(self):
        """Test case for check

        Checking the service availability.  # noqa: E501
        """
        pass

    def test_version(self):
        """Test case for version

        Getting the service version.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Veeroute.LSS Studio

    LSS Studio Tool API  # noqa: E501

    The version of the OpenAPI document: 3.8.168680
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_studio
from vrt_lss_studio.models.method_statistics import MethodStatistics  # noqa: E501
from vrt_lss_studio.rest import ApiException

class TestMethodStatistics(unittest.TestCase):
    """MethodStatistics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MethodStatistics
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_studio.models.method_statistics.MethodStatistics()  # noqa: E501
        if include_optional :
            return MethodStatistics(
                method = 'PLAN', 
                unique_points_per_day = 1500, 
                points_per_day = 1500
            )
        else :
            return MethodStatistics(
                method = 'PLAN',
                unique_points_per_day = 1500,
                points_per_day = 1500,
        )

    def testMethodStatistics(self):
        """Test MethodStatistics"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Veeroute.LSS Studio

    LSS Studio Tool API  # noqa: E501

    The version of the OpenAPI document: 3.8.168680
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from vrt_lss_studio.configuration import Configuration


class VersionResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'major': 'int',
        'minor': 'int',
        'build': 'int'
    }

    attribute_map = {
        'major': 'major',
        'minor': 'minor',
        'build': 'build'
    }

    def __init__(self, major=None, minor=None, build=None, local_vars_configuration=None):  # noqa: E501
        """VersionResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._major = None
        self._minor = None
        self._build = None
        self.discriminator = None

        self.major = major
        self.minor = minor
        self.build = build

    @property
    def major(self):
        """Gets the major of this VersionResult.  # noqa: E501

        Major version. Contains incompatible API changes.   # noqa: E501

        :return: The major of this VersionResult.  # noqa: E501
        :rtype: int
        """
        return self._major

    @major.setter
    def major(self, major):
        """Sets the major of this VersionResult.

        Major version. Contains incompatible API changes.   # noqa: E501

        :param major: The major of this VersionResult.  # noqa: E501
        :type major: int
        """
        if self.local_vars_configuration.client_side_validation and major is None:  # noqa: E501
            raise ValueError("Invalid value for `major`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                major is not None and major > 100):  # noqa: E501
            raise ValueError("Invalid value for `major`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                major is not None and major < 0):  # noqa: E501
            raise ValueError("Invalid value for `major`, must be a value greater than or equal to `0`")  # noqa: E501

        self._major = major

    @property
    def minor(self):
        """Gets the minor of this VersionResult.  # noqa: E501

        Minor version. Contains new functionality in a backwards compatible manner.   # noqa: E501

        :return: The minor of this VersionResult.  # noqa: E501
        :rtype: int
        """
        return self._minor

    @minor.setter
    def minor(self, minor):
        """Sets the minor of this VersionResult.

        Minor version. Contains new functionality in a backwards compatible manner.   # noqa: E501

        :param minor: The minor of this VersionResult.  # noqa: E501
        :type minor: int
        """
        if self.local_vars_configuration.client_side_validation and minor is None:  # noqa: E501
            raise ValueError("Invalid value for `minor`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                minor is not None and minor > 100):  # noqa: E501
            raise ValueError("Invalid value for `minor`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                minor is not None and minor < 0):  # noqa: E501
            raise ValueError("Invalid value for `minor`, must be a value greater than or equal to `0`")  # noqa: E501

        self._minor = minor

    @property
    def build(self):
        """Gets the build of this VersionResult.  # noqa: E501

        Build version. Contains backwards compatible bug fixes and docs update.   # noqa: E501

        :return: The build of this VersionResult.  # noqa: E501
        :rtype: int
        """
        return self._build

    @build.setter
    def build(self, build):
        """Sets the build of this VersionResult.

        Build version. Contains backwards compatible bug fixes and docs update.   # noqa: E501

        :param build: The build of this VersionResult.  # noqa: E501
        :type build: int
        """
        if self.local_vars_configuration.client_side_validation and build is None:  # noqa: E501
            raise ValueError("Invalid value for `build`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                build is not None and build > 1000000):  # noqa: E501
            raise ValueError("Invalid value for `build`, must be a value less than or equal to `1000000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                build is not None and build < 0):  # noqa: E501
            raise ValueError("Invalid value for `build`, must be a value greater than or equal to `0`")  # noqa: E501

        self._build = build

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VersionResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VersionResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Veeroute.LSS Studio

    LSS Studio Tool API  # noqa: E501

    The version of the OpenAPI document: 3.8.168680
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_studio
from vrt_lss_studio.models.inline_response403 import InlineResponse403  # noqa: E501
from vrt_lss_studio.rest import ApiException

class TestInlineResponse403(unittest.TestCase):
    """InlineResponse403 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InlineResponse403
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_studio.models.inline_response403.InlineResponse403()  # noqa: E501
        if include_optional :
            return InlineResponse403(
                tracedata = vrt_lss_studio.models.trace_data.TraceData(
                    code = 'client_server_service_time_uuid', 
                    client = 'client_name', 
                    server = 'server_name', 
                    service = 'LASTMILE', 
                    method = 'PLAN', 
                    time = '2021-02-21T09:30+03:00', ), 
                message = 'Forbidden', 
                code = 1403
            )
        else :
            return InlineResponse403(
                code = 1403,
        )

    def testInlineResponse403(self):
        """Test InlineResponse403"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
